# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.smartcaptcha.v1 import captcha_pb2 as yandex_dot_cloud_dot_smartcaptcha_dot_v1_dot_captcha__pb2
from yandex.cloud.smartcaptcha.v1 import captcha_service_pb2 as yandex_dot_cloud_dot_smartcaptcha_dot_v1_dot_captcha__service__pb2


class CaptchaServiceStub(object):
    """A set of methods for managing Captcha resources.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Get = channel.unary_unary(
                '/yandex.cloud.smartcaptcha.v1.CaptchaService/Get',
                request_serializer=yandex_dot_cloud_dot_smartcaptcha_dot_v1_dot_captcha__service__pb2.GetCaptchaRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_smartcaptcha_dot_v1_dot_captcha__pb2.Captcha.FromString,
                )
        self.GetSecretKey = channel.unary_unary(
                '/yandex.cloud.smartcaptcha.v1.CaptchaService/GetSecretKey',
                request_serializer=yandex_dot_cloud_dot_smartcaptcha_dot_v1_dot_captcha__service__pb2.GetCaptchaRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_smartcaptcha_dot_v1_dot_captcha__pb2.CaptchaSecretKey.FromString,
                )
        self.List = channel.unary_unary(
                '/yandex.cloud.smartcaptcha.v1.CaptchaService/List',
                request_serializer=yandex_dot_cloud_dot_smartcaptcha_dot_v1_dot_captcha__service__pb2.ListCaptchasRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_smartcaptcha_dot_v1_dot_captcha__service__pb2.ListCaptchasResponse.FromString,
                )
        self.Create = channel.unary_unary(
                '/yandex.cloud.smartcaptcha.v1.CaptchaService/Create',
                request_serializer=yandex_dot_cloud_dot_smartcaptcha_dot_v1_dot_captcha__service__pb2.CreateCaptchaRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Update = channel.unary_unary(
                '/yandex.cloud.smartcaptcha.v1.CaptchaService/Update',
                request_serializer=yandex_dot_cloud_dot_smartcaptcha_dot_v1_dot_captcha__service__pb2.UpdateCaptchaRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Delete = channel.unary_unary(
                '/yandex.cloud.smartcaptcha.v1.CaptchaService/Delete',
                request_serializer=yandex_dot_cloud_dot_smartcaptcha_dot_v1_dot_captcha__service__pb2.DeleteCaptchaRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )


class CaptchaServiceServicer(object):
    """A set of methods for managing Captcha resources.
    """

    def Get(self, request, context):
        """Returns the specified Captcha resource.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSecretKey(self, request, context):
        """Returns the secret data of specified Captcha resource.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Retrieves the list of Captcha resources in the specified folder.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Create(self, request, context):
        """Creates a captcha in the specified folder using the data specified in the request.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Updates the specified captcha.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Deletes the specified captcha.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_CaptchaServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=yandex_dot_cloud_dot_smartcaptcha_dot_v1_dot_captcha__service__pb2.GetCaptchaRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_smartcaptcha_dot_v1_dot_captcha__pb2.Captcha.SerializeToString,
            ),
            'GetSecretKey': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSecretKey,
                    request_deserializer=yandex_dot_cloud_dot_smartcaptcha_dot_v1_dot_captcha__service__pb2.GetCaptchaRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_smartcaptcha_dot_v1_dot_captcha__pb2.CaptchaSecretKey.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=yandex_dot_cloud_dot_smartcaptcha_dot_v1_dot_captcha__service__pb2.ListCaptchasRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_smartcaptcha_dot_v1_dot_captcha__service__pb2.ListCaptchasResponse.SerializeToString,
            ),
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=yandex_dot_cloud_dot_smartcaptcha_dot_v1_dot_captcha__service__pb2.CreateCaptchaRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=yandex_dot_cloud_dot_smartcaptcha_dot_v1_dot_captcha__service__pb2.UpdateCaptchaRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=yandex_dot_cloud_dot_smartcaptcha_dot_v1_dot_captcha__service__pb2.DeleteCaptchaRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.smartcaptcha.v1.CaptchaService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class CaptchaService(object):
    """A set of methods for managing Captcha resources.
    """

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.smartcaptcha.v1.CaptchaService/Get',
            yandex_dot_cloud_dot_smartcaptcha_dot_v1_dot_captcha__service__pb2.GetCaptchaRequest.SerializeToString,
            yandex_dot_cloud_dot_smartcaptcha_dot_v1_dot_captcha__pb2.Captcha.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSecretKey(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.smartcaptcha.v1.CaptchaService/GetSecretKey',
            yandex_dot_cloud_dot_smartcaptcha_dot_v1_dot_captcha__service__pb2.GetCaptchaRequest.SerializeToString,
            yandex_dot_cloud_dot_smartcaptcha_dot_v1_dot_captcha__pb2.CaptchaSecretKey.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.smartcaptcha.v1.CaptchaService/List',
            yandex_dot_cloud_dot_smartcaptcha_dot_v1_dot_captcha__service__pb2.ListCaptchasRequest.SerializeToString,
            yandex_dot_cloud_dot_smartcaptcha_dot_v1_dot_captcha__service__pb2.ListCaptchasResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.smartcaptcha.v1.CaptchaService/Create',
            yandex_dot_cloud_dot_smartcaptcha_dot_v1_dot_captcha__service__pb2.CreateCaptchaRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.smartcaptcha.v1.CaptchaService/Update',
            yandex_dot_cloud_dot_smartcaptcha_dot_v1_dot_captcha__service__pb2.UpdateCaptchaRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.smartcaptcha.v1.CaptchaService/Delete',
            yandex_dot_cloud_dot_smartcaptcha_dot_v1_dot_captcha__service__pb2.DeleteCaptchaRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
