# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/loadtesting/api/v1/config/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3yandex/cloud/loadtesting/api/v1/config/config.proto\x12&yandex.cloud.loadtesting.api.v1.config\x1a\x1fgoogle/protobuf/timestamp.proto\"\x94\x01\n\x06\x43onfig\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12\x13\n\x0byaml_string\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\n \x01(\t\x12.\n\ncreated_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x0c \x01(\tJ\x04\x08\x04\x10\nB\x7f\n*yandex.cloud.api.loadtesting.api.v1.configZQgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1/config;configb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.loadtesting.api.v1.config.config_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n*yandex.cloud.api.loadtesting.api.v1.configZQgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1/config;config'
  _globals['_CONFIG']._serialized_start=129
  _globals['_CONFIG']._serialized_end=277
# @@protoc_insertion_point(module_scope)
